@@ -3,18 +3,21 @@ Main interface for wafv2 service type definitions.
 
 Usage::
 
-    from mypy_boto3.wafv2.type_defs import CheckCapacityResponseTypeDef
+    ```python
+    from mypy_boto3_wafv2.type_defs import AndStatementTypeDef
 
-    data: CheckCapacityResponseTypeDef = {...}
+    data: AndStatementTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
-from typing import Any, Dict, IO, List, Union
+from datetime import datetime
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,69 +25,75 @@ else:
 
 
 __all__ = (
-    "CheckCapacityResponseTypeDef",
-    "IPSetSummaryTypeDef",
-    "CreateIPSetResponseTypeDef",
-    "RegexPatternSetSummaryTypeDef",
-    "CreateRegexPatternSetResponseTypeDef",
-    "RuleGroupSummaryTypeDef",
-    "CreateRuleGroupResponseTypeDef",
-    "WebACLSummaryTypeDef",
-    "CreateWebACLResponseTypeDef",
-    "DefaultActionTypeDef",
-    "RuleActionTypeDef",
-    "RuleSummaryTypeDef",
-    "DescribeManagedRuleGroupResponseTypeDef",
-    "IPSetTypeDef",
-    "GetIPSetResponseTypeDef",
-    "SingleHeaderTypeDef",
-    "SingleQueryArgumentTypeDef",
-    "FieldToMatchTypeDef",
-    "LoggingConfigurationTypeDef",
-    "GetLoggingConfigurationResponseTypeDef",
-    "RateBasedStatementManagedKeysIPSetTypeDef",
-    "GetRateBasedStatementManagedKeysResponseTypeDef",
-    "RegexTypeDef",
-    "RegexPatternSetTypeDef",
-    "GetRegexPatternSetResponseTypeDef",
-    "OverrideActionTypeDef",
     "AndStatementTypeDef",
-    "TextTransformationTypeDef",
     "ByteMatchStatementTypeDef",
-    "GeoMatchStatementTypeDef",
-    "IPSetReferenceStatementTypeDef",
+    "DefaultActionTypeDef",
     "ExcludedRuleTypeDef",
-    "ManagedRuleGroupStatementTypeDef",
-    "NotStatementTypeDef",
-    "OrStatementTypeDef",
-    "RateBasedStatementTypeDef",
-    "RegexPatternSetReferenceStatementTypeDef",
-    "RuleGroupReferenceStatementTypeDef",
-    "SizeConstraintStatementTypeDef",
-    "SqliMatchStatementTypeDef",
-    "XssMatchStatementTypeDef",
-    "StatementTypeDef",
-    "VisibilityConfigTypeDef",
-    "RuleTypeDef",
-    "RuleGroupTypeDef",
-    "GetRuleGroupResponseTypeDef",
+    "FieldToMatchTypeDef",
+    "FirewallManagerRuleGroupTypeDef",
+    "FirewallManagerStatementTypeDef",
+    "ForwardedIPConfigTypeDef",
+    "GeoMatchStatementTypeDef",
     "HTTPHeaderTypeDef",
     "HTTPRequestTypeDef",
+    "IPSetForwardedIPConfigTypeDef",
+    "IPSetReferenceStatementTypeDef",
+    "IPSetSummaryTypeDef",
+    "IPSetTypeDef",
+    "LoggingConfigurationTypeDef",
+    "ManagedRuleGroupStatementTypeDef",
+    "ManagedRuleGroupSummaryTypeDef",
+    "NotStatementTypeDef",
+    "OrStatementTypeDef",
+    "OverrideActionTypeDef",
+    "RateBasedStatementManagedKeysIPSetTypeDef",
+    "RateBasedStatementTypeDef",
+    "RegexPatternSetReferenceStatementTypeDef",
+    "RegexPatternSetSummaryTypeDef",
+    "RegexPatternSetTypeDef",
+    "RegexTypeDef",
+    "RuleActionTypeDef",
+    "RuleGroupReferenceStatementTypeDef",
+    "RuleGroupSummaryTypeDef",
+    "RuleGroupTypeDef",
+    "RuleSummaryTypeDef",
+    "RuleTypeDef",
     "SampledHTTPRequestTypeDef",
+    "SingleHeaderTypeDef",
+    "SingleQueryArgumentTypeDef",
+    "SizeConstraintStatementTypeDef",
+    "SqliMatchStatementTypeDef",
+    "TagInfoForResourceTypeDef",
+    "TagTypeDef",
+    "TextTransformationTypeDef",
     "TimeWindowTypeDef",
-    "GetSampledRequestsResponseTypeDef",
+    "VisibilityConfigTypeDef",
+    "WebACLSummaryTypeDef",
     "WebACLTypeDef",
+    "XssMatchStatementTypeDef",
+    "CheckCapacityResponseTypeDef",
+    "CreateIPSetResponseTypeDef",
+    "CreateRegexPatternSetResponseTypeDef",
+    "CreateRuleGroupResponseTypeDef",
+    "CreateWebACLResponseTypeDef",
+    "DeleteFirewallManagerRuleGroupsResponseTypeDef",
+    "DescribeManagedRuleGroupResponseTypeDef",
+    "StatementTypeDef",
+    "GetIPSetResponseTypeDef",
+    "GetLoggingConfigurationResponseTypeDef",
+    "GetPermissionPolicyResponseTypeDef",
+    "GetRateBasedStatementManagedKeysResponseTypeDef",
+    "GetRegexPatternSetResponseTypeDef",
+    "GetRuleGroupResponseTypeDef",
+    "GetSampledRequestsResponseTypeDef",
     "GetWebACLForResourceResponseTypeDef",
     "GetWebACLResponseTypeDef",
-    "ManagedRuleGroupSummaryTypeDef",
     "ListAvailableManagedRuleGroupsResponseTypeDef",
     "ListIPSetsResponseTypeDef",
     "ListLoggingConfigurationsResponseTypeDef",
     "ListRegexPatternSetsResponseTypeDef",
     "ListResourcesForWebACLResponseTypeDef",
     "ListRuleGroupsResponseTypeDef",
-    "TagTypeDef",
-    "TagInfoForResourceTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListWebACLsResponseTypeDef",
     "PutLoggingConfigurationResponseTypeDef",
@@ -94,100 +103,31 @@ __all__ = (
     "UpdateWebACLResponseTypeDef",
 )
 
-CheckCapacityResponseTypeDef = TypedDict(
-    "CheckCapacityResponseTypeDef", {"Capacity": int}, total=False
-)
+AndStatementTypeDef = TypedDict("AndStatementTypeDef", {"Statements": List[Dict[str, Any]]})
 
-IPSetSummaryTypeDef = TypedDict(
-    "IPSetSummaryTypeDef",
-    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
-    total=False,
-)
-
-CreateIPSetResponseTypeDef = TypedDict(
-    "CreateIPSetResponseTypeDef", {"Summary": IPSetSummaryTypeDef}, total=False
-)
-
-RegexPatternSetSummaryTypeDef = TypedDict(
-    "RegexPatternSetSummaryTypeDef",
-    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
-    total=False,
-)
-
-CreateRegexPatternSetResponseTypeDef = TypedDict(
-    "CreateRegexPatternSetResponseTypeDef", {"Summary": RegexPatternSetSummaryTypeDef}, total=False
-)
-
-RuleGroupSummaryTypeDef = TypedDict(
-    "RuleGroupSummaryTypeDef",
-    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
-    total=False,
-)
-
-CreateRuleGroupResponseTypeDef = TypedDict(
-    "CreateRuleGroupResponseTypeDef", {"Summary": RuleGroupSummaryTypeDef}, total=False
-)
-
-WebACLSummaryTypeDef = TypedDict(
-    "WebACLSummaryTypeDef",
-    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
-    total=False,
-)
-
-CreateWebACLResponseTypeDef = TypedDict(
-    "CreateWebACLResponseTypeDef", {"Summary": WebACLSummaryTypeDef}, total=False
+ByteMatchStatementTypeDef = TypedDict(
+    "ByteMatchStatementTypeDef",
+    {
+        "SearchString": bytes,
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "TextTransformations": List["TextTransformationTypeDef"],
+        "PositionalConstraint": Literal[
+            "EXACTLY", "STARTS_WITH", "ENDS_WITH", "CONTAINS", "CONTAINS_WORD"
+        ],
+    },
 )
 
 DefaultActionTypeDef = TypedDict(
     "DefaultActionTypeDef", {"Block": Dict[str, Any], "Allow": Dict[str, Any]}, total=False
 )
 
-RuleActionTypeDef = TypedDict(
-    "RuleActionTypeDef",
-    {"Block": Dict[str, Any], "Allow": Dict[str, Any], "Count": Dict[str, Any]},
-    total=False,
-)
-
-RuleSummaryTypeDef = TypedDict(
-    "RuleSummaryTypeDef", {"Name": str, "Action": RuleActionTypeDef}, total=False
-)
-
-DescribeManagedRuleGroupResponseTypeDef = TypedDict(
-    "DescribeManagedRuleGroupResponseTypeDef",
-    {"Capacity": int, "Rules": List[RuleSummaryTypeDef]},
-    total=False,
-)
-
-_RequiredIPSetTypeDef = TypedDict(
-    "_RequiredIPSetTypeDef",
-    {
-        "Name": str,
-        "Id": str,
-        "ARN": str,
-        "IPAddressVersion": Literal["IPV4", "IPV6"],
-        "Addresses": List[str],
-    },
-)
-_OptionalIPSetTypeDef = TypedDict("_OptionalIPSetTypeDef", {"Description": str}, total=False)
-
-
-class IPSetTypeDef(_RequiredIPSetTypeDef, _OptionalIPSetTypeDef):
-    pass
-
-
-GetIPSetResponseTypeDef = TypedDict(
-    "GetIPSetResponseTypeDef", {"IPSet": IPSetTypeDef, "LockToken": str}, total=False
-)
-
-SingleHeaderTypeDef = TypedDict("SingleHeaderTypeDef", {"Name": str})
-
-SingleQueryArgumentTypeDef = TypedDict("SingleQueryArgumentTypeDef", {"Name": str})
+ExcludedRuleTypeDef = TypedDict("ExcludedRuleTypeDef", {"Name": str})
 
 FieldToMatchTypeDef = TypedDict(
     "FieldToMatchTypeDef",
     {
-        "SingleHeader": SingleHeaderTypeDef,
-        "SingleQueryArgument": SingleQueryArgumentTypeDef,
+        "SingleHeader": "SingleHeaderTypeDef",
+        "SingleQueryArgument": "SingleQueryArgumentTypeDef",
         "AllQueryArguments": Dict[str, Any],
         "UriPath": Dict[str, Any],
         "QueryString": Dict[str, Any],
@@ -197,94 +137,29 @@ FieldToMatchTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredLoggingConfigurationTypeDef = TypedDict(
-    "_RequiredLoggingConfigurationTypeDef", {"ResourceArn": str, "LogDestinationConfigs": List[str]}
-)
-_OptionalLoggingConfigurationTypeDef = TypedDict(
-    "_OptionalLoggingConfigurationTypeDef",
-    {"RedactedFields": List[FieldToMatchTypeDef]},
-    total=False,
-)
-
-
-class LoggingConfigurationTypeDef(
-    _RequiredLoggingConfigurationTypeDef, _OptionalLoggingConfigurationTypeDef
-):
-    pass
-
-
-GetLoggingConfigurationResponseTypeDef = TypedDict(
-    "GetLoggingConfigurationResponseTypeDef",
-    {"LoggingConfiguration": LoggingConfigurationTypeDef},
-    total=False,
-)
-
-RateBasedStatementManagedKeysIPSetTypeDef = TypedDict(
-    "RateBasedStatementManagedKeysIPSetTypeDef",
-    {"IPAddressVersion": Literal["IPV4", "IPV6"], "Addresses": List[str]},
-    total=False,
-)
-
-GetRateBasedStatementManagedKeysResponseTypeDef = TypedDict(
-    "GetRateBasedStatementManagedKeysResponseTypeDef",
-    {
-        "ManagedKeysIPV4": RateBasedStatementManagedKeysIPSetTypeDef,
-        "ManagedKeysIPV6": RateBasedStatementManagedKeysIPSetTypeDef,
-    },
-    total=False,
-)
-
-RegexTypeDef = TypedDict("RegexTypeDef", {"RegexString": str}, total=False)
-
-RegexPatternSetTypeDef = TypedDict(
-    "RegexPatternSetTypeDef",
+FirewallManagerRuleGroupTypeDef = TypedDict(
+    "FirewallManagerRuleGroupTypeDef",
     {
         "Name": str,
-        "Id": str,
-        "ARN": str,
-        "Description": str,
-        "RegularExpressionList": List[RegexTypeDef],
-    },
-    total=False,
-)
-
-GetRegexPatternSetResponseTypeDef = TypedDict(
-    "GetRegexPatternSetResponseTypeDef",
-    {"RegexPatternSet": RegexPatternSetTypeDef, "LockToken": str},
-    total=False,
-)
-
-OverrideActionTypeDef = TypedDict(
-    "OverrideActionTypeDef", {"Count": Dict[str, Any], "None": Dict[str, Any]}, total=False
-)
-
-AndStatementTypeDef = TypedDict("AndStatementTypeDef", {"Statements": List[StatementTypeDef]})
-
-TextTransformationTypeDef = TypedDict(
-    "TextTransformationTypeDef",
-    {
         "Priority": int,
-        "Type": Literal[
-            "NONE",
-            "COMPRESS_WHITE_SPACE",
-            "HTML_ENTITY_DECODE",
-            "LOWERCASE",
-            "CMD_LINE",
-            "URL_DECODE",
-        ],
+        "FirewallManagerStatement": "FirewallManagerStatementTypeDef",
+        "OverrideAction": "OverrideActionTypeDef",
+        "VisibilityConfig": "VisibilityConfigTypeDef",
     },
 )
 
-ByteMatchStatementTypeDef = TypedDict(
-    "ByteMatchStatementTypeDef",
+FirewallManagerStatementTypeDef = TypedDict(
+    "FirewallManagerStatementTypeDef",
     {
-        "SearchString": Union[bytes, IO],
-        "FieldToMatch": FieldToMatchTypeDef,
-        "TextTransformations": List[TextTransformationTypeDef],
-        "PositionalConstraint": Literal[
-            "EXACTLY", "STARTS_WITH", "ENDS_WITH", "CONTAINS", "CONTAINS_WORD"
-        ],
+        "ManagedRuleGroupStatement": "ManagedRuleGroupStatementTypeDef",
+        "RuleGroupReferenceStatement": "RuleGroupReferenceStatementTypeDef",
     },
+    total=False,
+)
+
+ForwardedIPConfigTypeDef = TypedDict(
+    "ForwardedIPConfigTypeDef",
+    {"HeaderName": str, "FallbackBehavior": Literal["MATCH", "NO_MATCH"]},
 )
 
 GeoMatchStatementTypeDef = TypedDict(
@@ -542,21 +417,97 @@ GeoMatchStatementTypeDef = TypedDict(
                 "ZM",
                 "ZW",
             ]
-        ]
+        ],
+        "ForwardedIPConfig": "ForwardedIPConfigTypeDef",
     },
     total=False,
 )
 
-IPSetReferenceStatementTypeDef = TypedDict("IPSetReferenceStatementTypeDef", {"ARN": str})
+HTTPHeaderTypeDef = TypedDict("HTTPHeaderTypeDef", {"Name": str, "Value": str}, total=False)
+
+HTTPRequestTypeDef = TypedDict(
+    "HTTPRequestTypeDef",
+    {
+        "ClientIP": str,
+        "Country": str,
+        "URI": str,
+        "Method": str,
+        "HTTPVersion": str,
+        "Headers": List["HTTPHeaderTypeDef"],
+    },
+    total=False,
+)
+
+IPSetForwardedIPConfigTypeDef = TypedDict(
+    "IPSetForwardedIPConfigTypeDef",
+    {
+        "HeaderName": str,
+        "FallbackBehavior": Literal["MATCH", "NO_MATCH"],
+        "Position": Literal["FIRST", "LAST", "ANY"],
+    },
+)
+
+_RequiredIPSetReferenceStatementTypeDef = TypedDict(
+    "_RequiredIPSetReferenceStatementTypeDef", {"ARN": str}
+)
+_OptionalIPSetReferenceStatementTypeDef = TypedDict(
+    "_OptionalIPSetReferenceStatementTypeDef",
+    {"IPSetForwardedIPConfig": "IPSetForwardedIPConfigTypeDef"},
+    total=False,
+)
+
+
+class IPSetReferenceStatementTypeDef(
+    _RequiredIPSetReferenceStatementTypeDef, _OptionalIPSetReferenceStatementTypeDef
+):
+    pass
+
+
+IPSetSummaryTypeDef = TypedDict(
+    "IPSetSummaryTypeDef",
+    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
+    total=False,
+)
+
+_RequiredIPSetTypeDef = TypedDict(
+    "_RequiredIPSetTypeDef",
+    {
+        "Name": str,
+        "Id": str,
+        "ARN": str,
+        "IPAddressVersion": Literal["IPV4", "IPV6"],
+        "Addresses": List[str],
+    },
+)
+_OptionalIPSetTypeDef = TypedDict("_OptionalIPSetTypeDef", {"Description": str}, total=False)
+
+
+class IPSetTypeDef(_RequiredIPSetTypeDef, _OptionalIPSetTypeDef):
+    pass
+
+
+_RequiredLoggingConfigurationTypeDef = TypedDict(
+    "_RequiredLoggingConfigurationTypeDef", {"ResourceArn": str, "LogDestinationConfigs": List[str]}
+)
+_OptionalLoggingConfigurationTypeDef = TypedDict(
+    "_OptionalLoggingConfigurationTypeDef",
+    {"RedactedFields": List["FieldToMatchTypeDef"], "ManagedByFirewallManager": bool},
+    total=False,
+)
+
+
+class LoggingConfigurationTypeDef(
+    _RequiredLoggingConfigurationTypeDef, _OptionalLoggingConfigurationTypeDef
+):
+    pass
 
-ExcludedRuleTypeDef = TypedDict("ExcludedRuleTypeDef", {"Name": str})
 
 _RequiredManagedRuleGroupStatementTypeDef = TypedDict(
     "_RequiredManagedRuleGroupStatementTypeDef", {"VendorName": str, "Name": str}
 )
 _OptionalManagedRuleGroupStatementTypeDef = TypedDict(
     "_OptionalManagedRuleGroupStatementTypeDef",
-    {"ExcludedRules": List[ExcludedRuleTypeDef]},
+    {"ExcludedRules": List["ExcludedRuleTypeDef"]},
     total=False,
 )
 
@@ -567,15 +518,34 @@ class ManagedRuleGroupStatementTypeDef(
     pass
 
 
-NotStatementTypeDef = TypedDict("NotStatementTypeDef", {"Statement": StatementTypeDef})
+ManagedRuleGroupSummaryTypeDef = TypedDict(
+    "ManagedRuleGroupSummaryTypeDef",
+    {"VendorName": str, "Name": str, "Description": str},
+    total=False,
+)
 
-OrStatementTypeDef = TypedDict("OrStatementTypeDef", {"Statements": List[StatementTypeDef]})
+NotStatementTypeDef = TypedDict("NotStatementTypeDef", {"Statement": Dict[str, Any]})
+
+OrStatementTypeDef = TypedDict("OrStatementTypeDef", {"Statements": List[Dict[str, Any]]})
+
+OverrideActionTypeDef = TypedDict(
+    "OverrideActionTypeDef", {"Count": Dict[str, Any], "None": Dict[str, Any]}, total=False
+)
+
+RateBasedStatementManagedKeysIPSetTypeDef = TypedDict(
+    "RateBasedStatementManagedKeysIPSetTypeDef",
+    {"IPAddressVersion": Literal["IPV4", "IPV6"], "Addresses": List[str]},
+    total=False,
+)
 
 _RequiredRateBasedStatementTypeDef = TypedDict(
-    "_RequiredRateBasedStatementTypeDef", {"Limit": int, "AggregateKeyType": Literal["IP"]}
+    "_RequiredRateBasedStatementTypeDef",
+    {"Limit": int, "AggregateKeyType": Literal["IP", "FORWARDED_IP"]},
 )
 _OptionalRateBasedStatementTypeDef = TypedDict(
-    "_OptionalRateBasedStatementTypeDef", {"ScopeDownStatement": StatementTypeDef}, total=False
+    "_OptionalRateBasedStatementTypeDef",
+    {"ScopeDownStatement": Dict[str, Any], "ForwardedIPConfig": "ForwardedIPConfigTypeDef"},
+    total=False,
 )
 
 
@@ -589,17 +559,43 @@ RegexPatternSetReferenceStatementTypeDef = TypedDict(
     "RegexPatternSetReferenceStatementTypeDef",
     {
         "ARN": str,
-        "FieldToMatch": FieldToMatchTypeDef,
-        "TextTransformations": List[TextTransformationTypeDef],
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "TextTransformations": List["TextTransformationTypeDef"],
     },
 )
 
+RegexPatternSetSummaryTypeDef = TypedDict(
+    "RegexPatternSetSummaryTypeDef",
+    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
+    total=False,
+)
+
+RegexPatternSetTypeDef = TypedDict(
+    "RegexPatternSetTypeDef",
+    {
+        "Name": str,
+        "Id": str,
+        "ARN": str,
+        "Description": str,
+        "RegularExpressionList": List["RegexTypeDef"],
+    },
+    total=False,
+)
+
+RegexTypeDef = TypedDict("RegexTypeDef", {"RegexString": str}, total=False)
+
+RuleActionTypeDef = TypedDict(
+    "RuleActionTypeDef",
+    {"Block": Dict[str, Any], "Allow": Dict[str, Any], "Count": Dict[str, Any]},
+    total=False,
+)
+
 _RequiredRuleGroupReferenceStatementTypeDef = TypedDict(
     "_RequiredRuleGroupReferenceStatementTypeDef", {"ARN": str}
 )
 _OptionalRuleGroupReferenceStatementTypeDef = TypedDict(
     "_OptionalRuleGroupReferenceStatementTypeDef",
-    {"ExcludedRules": List[ExcludedRuleTypeDef]},
+    {"ExcludedRules": List["ExcludedRuleTypeDef"]},
     total=False,
 )
 
@@ -610,71 +606,12 @@ class RuleGroupReferenceStatementTypeDef(
     pass
 
 
-SizeConstraintStatementTypeDef = TypedDict(
-    "SizeConstraintStatementTypeDef",
-    {
-        "FieldToMatch": FieldToMatchTypeDef,
-        "ComparisonOperator": Literal["EQ", "NE", "LE", "LT", "GE", "GT"],
-        "Size": int,
-        "TextTransformations": List[TextTransformationTypeDef],
-    },
-)
-
-SqliMatchStatementTypeDef = TypedDict(
-    "SqliMatchStatementTypeDef",
-    {"FieldToMatch": FieldToMatchTypeDef, "TextTransformations": List[TextTransformationTypeDef]},
-)
-
-XssMatchStatementTypeDef = TypedDict(
-    "XssMatchStatementTypeDef",
-    {"FieldToMatch": FieldToMatchTypeDef, "TextTransformations": List[TextTransformationTypeDef]},
-)
-
-StatementTypeDef = TypedDict(
-    "StatementTypeDef",
-    {
-        "ByteMatchStatement": ByteMatchStatementTypeDef,
-        "SqliMatchStatement": SqliMatchStatementTypeDef,
-        "XssMatchStatement": XssMatchStatementTypeDef,
-        "SizeConstraintStatement": SizeConstraintStatementTypeDef,
-        "GeoMatchStatement": GeoMatchStatementTypeDef,
-        "RuleGroupReferenceStatement": RuleGroupReferenceStatementTypeDef,
-        "IPSetReferenceStatement": IPSetReferenceStatementTypeDef,
-        "RegexPatternSetReferenceStatement": RegexPatternSetReferenceStatementTypeDef,
-        "RateBasedStatement": RateBasedStatementTypeDef,
-        "AndStatement": AndStatementTypeDef,
-        "OrStatement": OrStatementTypeDef,
-        "NotStatement": NotStatementTypeDef,
-        "ManagedRuleGroupStatement": ManagedRuleGroupStatementTypeDef,
-    },
+RuleGroupSummaryTypeDef = TypedDict(
+    "RuleGroupSummaryTypeDef",
+    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
     total=False,
 )
 
-VisibilityConfigTypeDef = TypedDict(
-    "VisibilityConfigTypeDef",
-    {"SampledRequestsEnabled": bool, "CloudWatchMetricsEnabled": bool, "MetricName": str},
-)
-
-_RequiredRuleTypeDef = TypedDict(
-    "_RequiredRuleTypeDef",
-    {
-        "Name": str,
-        "Priority": int,
-        "Statement": StatementTypeDef,
-        "VisibilityConfig": VisibilityConfigTypeDef,
-    },
-)
-_OptionalRuleTypeDef = TypedDict(
-    "_OptionalRuleTypeDef",
-    {"Action": RuleActionTypeDef, "OverrideAction": OverrideActionTypeDef},
-    total=False,
-)
-
-
-class RuleTypeDef(_RequiredRuleTypeDef, _OptionalRuleTypeDef):
-    pass
-
-
 _RequiredRuleGroupTypeDef = TypedDict(
     "_RequiredRuleGroupTypeDef",
     {
@@ -682,11 +619,11 @@ _RequiredRuleGroupTypeDef = TypedDict(
         "Id": str,
         "Capacity": int,
         "ARN": str,
-        "VisibilityConfig": VisibilityConfigTypeDef,
+        "VisibilityConfig": "VisibilityConfigTypeDef",
     },
 )
 _OptionalRuleGroupTypeDef = TypedDict(
-    "_OptionalRuleGroupTypeDef", {"Description": str, "Rules": List[RuleTypeDef]}, total=False
+    "_OptionalRuleGroupTypeDef", {"Description": str, "Rules": List["RuleTypeDef"]}, total=False
 )
 
 
@@ -694,27 +631,32 @@ class RuleGroupTypeDef(_RequiredRuleGroupTypeDef, _OptionalRuleGroupTypeDef):
     pass
 
 
-GetRuleGroupResponseTypeDef = TypedDict(
-    "GetRuleGroupResponseTypeDef", {"RuleGroup": RuleGroupTypeDef, "LockToken": str}, total=False
+RuleSummaryTypeDef = TypedDict(
+    "RuleSummaryTypeDef", {"Name": str, "Action": "RuleActionTypeDef"}, total=False
 )
 
-HTTPHeaderTypeDef = TypedDict("HTTPHeaderTypeDef", {"Name": str, "Value": str}, total=False)
-
-HTTPRequestTypeDef = TypedDict(
-    "HTTPRequestTypeDef",
+_RequiredRuleTypeDef = TypedDict(
+    "_RequiredRuleTypeDef",
     {
-        "ClientIP": str,
-        "Country": str,
-        "URI": str,
-        "Method": str,
-        "HTTPVersion": str,
-        "Headers": List[HTTPHeaderTypeDef],
+        "Name": str,
+        "Priority": int,
+        "Statement": Dict[str, Any],
+        "VisibilityConfig": "VisibilityConfigTypeDef",
     },
+)
+_OptionalRuleTypeDef = TypedDict(
+    "_OptionalRuleTypeDef",
+    {"Action": "RuleActionTypeDef", "OverrideAction": "OverrideActionTypeDef"},
     total=False,
 )
 
+
+class RuleTypeDef(_RequiredRuleTypeDef, _OptionalRuleTypeDef):
+    pass
+
+
 _RequiredSampledHTTPRequestTypeDef = TypedDict(
-    "_RequiredSampledHTTPRequestTypeDef", {"Request": HTTPRequestTypeDef, "Weight": int}
+    "_RequiredSampledHTTPRequestTypeDef", {"Request": "HTTPRequestTypeDef", "Weight": int}
 )
 _OptionalSampledHTTPRequestTypeDef = TypedDict(
     "_OptionalSampledHTTPRequestTypeDef",
@@ -729,15 +671,59 @@ class SampledHTTPRequestTypeDef(
     pass
 
 
+SingleHeaderTypeDef = TypedDict("SingleHeaderTypeDef", {"Name": str})
+
+SingleQueryArgumentTypeDef = TypedDict("SingleQueryArgumentTypeDef", {"Name": str})
+
+SizeConstraintStatementTypeDef = TypedDict(
+    "SizeConstraintStatementTypeDef",
+    {
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "ComparisonOperator": Literal["EQ", "NE", "LE", "LT", "GE", "GT"],
+        "Size": int,
+        "TextTransformations": List["TextTransformationTypeDef"],
+    },
+)
+
+SqliMatchStatementTypeDef = TypedDict(
+    "SqliMatchStatementTypeDef",
+    {
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "TextTransformations": List["TextTransformationTypeDef"],
+    },
+)
+
+TagInfoForResourceTypeDef = TypedDict(
+    "TagInfoForResourceTypeDef", {"ResourceARN": str, "TagList": List["TagTypeDef"]}, total=False
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+TextTransformationTypeDef = TypedDict(
+    "TextTransformationTypeDef",
+    {
+        "Priority": int,
+        "Type": Literal[
+            "NONE",
+            "COMPRESS_WHITE_SPACE",
+            "HTML_ENTITY_DECODE",
+            "LOWERCASE",
+            "CMD_LINE",
+            "URL_DECODE",
+        ],
+    },
+)
+
 TimeWindowTypeDef = TypedDict("TimeWindowTypeDef", {"StartTime": datetime, "EndTime": datetime})
 
-GetSampledRequestsResponseTypeDef = TypedDict(
-    "GetSampledRequestsResponseTypeDef",
-    {
-        "SampledRequests": List[SampledHTTPRequestTypeDef],
-        "PopulationSize": int,
-        "TimeWindow": TimeWindowTypeDef,
-    },
+VisibilityConfigTypeDef = TypedDict(
+    "VisibilityConfigTypeDef",
+    {"SampledRequestsEnabled": bool, "CloudWatchMetricsEnabled": bool, "MetricName": str},
+)
+
+WebACLSummaryTypeDef = TypedDict(
+    "WebACLSummaryTypeDef",
+    {"Name": str, "Id": str, "Description": str, "LockToken": str, "ARN": str},
     total=False,
 )
 
@@ -747,13 +733,20 @@ _RequiredWebACLTypeDef = TypedDict(
         "Name": str,
         "Id": str,
         "ARN": str,
-        "DefaultAction": DefaultActionTypeDef,
-        "VisibilityConfig": VisibilityConfigTypeDef,
+        "DefaultAction": "DefaultActionTypeDef",
+        "VisibilityConfig": "VisibilityConfigTypeDef",
     },
 )
 _OptionalWebACLTypeDef = TypedDict(
     "_OptionalWebACLTypeDef",
-    {"Description": str, "Rules": List[RuleTypeDef], "Capacity": int},
+    {
+        "Description": str,
+        "Rules": List["RuleTypeDef"],
+        "Capacity": int,
+        "PreProcessFirewallManagerRuleGroups": List["FirewallManagerRuleGroupTypeDef"],
+        "PostProcessFirewallManagerRuleGroups": List["FirewallManagerRuleGroupTypeDef"],
+        "ManagedByFirewallManager": bool,
+    },
     total=False,
 )
 
@@ -762,41 +755,138 @@ class WebACLTypeDef(_RequiredWebACLTypeDef, _OptionalWebACLTypeDef):
     pass
 
 
+XssMatchStatementTypeDef = TypedDict(
+    "XssMatchStatementTypeDef",
+    {
+        "FieldToMatch": "FieldToMatchTypeDef",
+        "TextTransformations": List["TextTransformationTypeDef"],
+    },
+)
+
+CheckCapacityResponseTypeDef = TypedDict(
+    "CheckCapacityResponseTypeDef", {"Capacity": int}, total=False
+)
+
+CreateIPSetResponseTypeDef = TypedDict(
+    "CreateIPSetResponseTypeDef", {"Summary": "IPSetSummaryTypeDef"}, total=False
+)
+
+CreateRegexPatternSetResponseTypeDef = TypedDict(
+    "CreateRegexPatternSetResponseTypeDef",
+    {"Summary": "RegexPatternSetSummaryTypeDef"},
+    total=False,
+)
+
+CreateRuleGroupResponseTypeDef = TypedDict(
+    "CreateRuleGroupResponseTypeDef", {"Summary": "RuleGroupSummaryTypeDef"}, total=False
+)
+
+CreateWebACLResponseTypeDef = TypedDict(
+    "CreateWebACLResponseTypeDef", {"Summary": "WebACLSummaryTypeDef"}, total=False
+)
+
+DeleteFirewallManagerRuleGroupsResponseTypeDef = TypedDict(
+    "DeleteFirewallManagerRuleGroupsResponseTypeDef", {"NextWebACLLockToken": str}, total=False
+)
+
+DescribeManagedRuleGroupResponseTypeDef = TypedDict(
+    "DescribeManagedRuleGroupResponseTypeDef",
+    {"Capacity": int, "Rules": List["RuleSummaryTypeDef"]},
+    total=False,
+)
+
+StatementTypeDef = TypedDict(
+    "StatementTypeDef",
+    {
+        "ByteMatchStatement": "ByteMatchStatementTypeDef",
+        "SqliMatchStatement": "SqliMatchStatementTypeDef",
+        "XssMatchStatement": "XssMatchStatementTypeDef",
+        "SizeConstraintStatement": "SizeConstraintStatementTypeDef",
+        "GeoMatchStatement": "GeoMatchStatementTypeDef",
+        "RuleGroupReferenceStatement": "RuleGroupReferenceStatementTypeDef",
+        "IPSetReferenceStatement": "IPSetReferenceStatementTypeDef",
+        "RegexPatternSetReferenceStatement": "RegexPatternSetReferenceStatementTypeDef",
+        "RateBasedStatement": "RateBasedStatementTypeDef",
+        "AndStatement": "AndStatementTypeDef",
+        "OrStatement": "OrStatementTypeDef",
+        "NotStatement": "NotStatementTypeDef",
+        "ManagedRuleGroupStatement": "ManagedRuleGroupStatementTypeDef",
+    },
+    total=False,
+)
+
+GetIPSetResponseTypeDef = TypedDict(
+    "GetIPSetResponseTypeDef", {"IPSet": "IPSetTypeDef", "LockToken": str}, total=False
+)
+
+GetLoggingConfigurationResponseTypeDef = TypedDict(
+    "GetLoggingConfigurationResponseTypeDef",
+    {"LoggingConfiguration": "LoggingConfigurationTypeDef"},
+    total=False,
+)
+
+GetPermissionPolicyResponseTypeDef = TypedDict(
+    "GetPermissionPolicyResponseTypeDef", {"Policy": str}, total=False
+)
+
+GetRateBasedStatementManagedKeysResponseTypeDef = TypedDict(
+    "GetRateBasedStatementManagedKeysResponseTypeDef",
+    {
+        "ManagedKeysIPV4": "RateBasedStatementManagedKeysIPSetTypeDef",
+        "ManagedKeysIPV6": "RateBasedStatementManagedKeysIPSetTypeDef",
+    },
+    total=False,
+)
+
+GetRegexPatternSetResponseTypeDef = TypedDict(
+    "GetRegexPatternSetResponseTypeDef",
+    {"RegexPatternSet": "RegexPatternSetTypeDef", "LockToken": str},
+    total=False,
+)
+
+GetRuleGroupResponseTypeDef = TypedDict(
+    "GetRuleGroupResponseTypeDef", {"RuleGroup": "RuleGroupTypeDef", "LockToken": str}, total=False
+)
+
+GetSampledRequestsResponseTypeDef = TypedDict(
+    "GetSampledRequestsResponseTypeDef",
+    {
+        "SampledRequests": List["SampledHTTPRequestTypeDef"],
+        "PopulationSize": int,
+        "TimeWindow": "TimeWindowTypeDef",
+    },
+    total=False,
+)
+
 GetWebACLForResourceResponseTypeDef = TypedDict(
-    "GetWebACLForResourceResponseTypeDef", {"WebACL": WebACLTypeDef}, total=False
+    "GetWebACLForResourceResponseTypeDef", {"WebACL": "WebACLTypeDef"}, total=False
 )
 
 GetWebACLResponseTypeDef = TypedDict(
-    "GetWebACLResponseTypeDef", {"WebACL": WebACLTypeDef, "LockToken": str}, total=False
-)
-
-ManagedRuleGroupSummaryTypeDef = TypedDict(
-    "ManagedRuleGroupSummaryTypeDef",
-    {"VendorName": str, "Name": str, "Description": str},
-    total=False,
+    "GetWebACLResponseTypeDef", {"WebACL": "WebACLTypeDef", "LockToken": str}, total=False
 )
 
 ListAvailableManagedRuleGroupsResponseTypeDef = TypedDict(
     "ListAvailableManagedRuleGroupsResponseTypeDef",
-    {"NextMarker": str, "ManagedRuleGroups": List[ManagedRuleGroupSummaryTypeDef]},
+    {"NextMarker": str, "ManagedRuleGroups": List["ManagedRuleGroupSummaryTypeDef"]},
     total=False,
 )
 
 ListIPSetsResponseTypeDef = TypedDict(
     "ListIPSetsResponseTypeDef",
-    {"NextMarker": str, "IPSets": List[IPSetSummaryTypeDef]},
+    {"NextMarker": str, "IPSets": List["IPSetSummaryTypeDef"]},
     total=False,
 )
 
 ListLoggingConfigurationsResponseTypeDef = TypedDict(
     "ListLoggingConfigurationsResponseTypeDef",
-    {"LoggingConfigurations": List[LoggingConfigurationTypeDef], "NextMarker": str},
+    {"LoggingConfigurations": List["LoggingConfigurationTypeDef"], "NextMarker": str},
     total=False,
 )
 
 ListRegexPatternSetsResponseTypeDef = TypedDict(
     "ListRegexPatternSetsResponseTypeDef",
-    {"NextMarker": str, "RegexPatternSets": List[RegexPatternSetSummaryTypeDef]},
+    {"NextMarker": str, "RegexPatternSets": List["RegexPatternSetSummaryTypeDef"]},
     total=False,
 )
 
@@ -806,31 +896,25 @@ ListResourcesForWebACLResponseTypeDef = TypedDict(
 
 ListRuleGroupsResponseTypeDef = TypedDict(
     "ListRuleGroupsResponseTypeDef",
-    {"NextMarker": str, "RuleGroups": List[RuleGroupSummaryTypeDef]},
+    {"NextMarker": str, "RuleGroups": List["RuleGroupSummaryTypeDef"]},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
-TagInfoForResourceTypeDef = TypedDict(
-    "TagInfoForResourceTypeDef", {"ResourceARN": str, "TagList": List[TagTypeDef]}, total=False
-)
-
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
-    {"NextMarker": str, "TagInfoForResource": TagInfoForResourceTypeDef},
+    {"NextMarker": str, "TagInfoForResource": "TagInfoForResourceTypeDef"},
     total=False,
 )
 
 ListWebACLsResponseTypeDef = TypedDict(
     "ListWebACLsResponseTypeDef",
-    {"NextMarker": str, "WebACLs": List[WebACLSummaryTypeDef]},
+    {"NextMarker": str, "WebACLs": List["WebACLSummaryTypeDef"]},
     total=False,
 )
 
 PutLoggingConfigurationResponseTypeDef = TypedDict(
     "PutLoggingConfigurationResponseTypeDef",
-    {"LoggingConfiguration": LoggingConfigurationTypeDef},
+    {"LoggingConfiguration": "LoggingConfigurationTypeDef"},
     total=False,
 )
 
